<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bg">
<context>
    <name>MircastShowWidget</name>
    <message>
        <source>Projecting... 
Please do not exit the Movie app during the process.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit Miracast</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MircastWidget</name>
    <message>
        <source>Project to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Searching for devices...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Miracast display devices were found. Please connect the device and your computer to the same WLAN network.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Invalid folder</source>
        <translation>Невалидна папка</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Отваряне на папка</translation>
    </message>
    <message>
        <source>Network disconnected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Нямата права да работите в тази папка</translation>
    </message>
    <message>
        <source>Auto add similar files to play</source>
        <translation>Атоматочно добави на подобни файлове</translation>
    </message>
    <message>
        <source>Clear playlist when exit</source>
        <translation>Изчистване на списъка при изход</translation>
    </message>
    <message>
        <source>Show video preview on mouseover</source>
        <translation>Покажи преглед при посочване с мишката</translation>
    </message>
    <message>
        <source>Open a new player for each file played</source>
        <translation>Нов плеър за всеки просвирван файл</translation>
    </message>
    <message>
        <source>Pause when minimized</source>
        <translation>Пауза при минимизиране</translation>
    </message>
    <message>
        <source>Remember playback position</source>
        <translation>Запомни местоположението на записа</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Път</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Основен</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Изпълнение</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Снимка на екрана</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Бързи клавиши</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <source>Frame/Sound</source>
        <translation>Кадър/Звук</translation>
    </message>
    <message>
        <source>Playback</source>
        <translation>Изпълнение</translation>
    </message>
    <message>
        <source>Subtitle</source>
        <translation>Субтитри</translation>
    </message>
    <message>
        <source>Font Style</source>
        <translation>Стил на шрифта:</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Възстанови стандартните настройки</translation>
    </message>
    <message>
        <source>Open file</source>
        <translation>Отвори файл</translation>
    </message>
    <message>
        <source>Open next</source>
        <translation>Отвори следващото</translation>
    </message>
    <message>
        <source>Open previous</source>
        <translation>Отвори предишното</translation>
    </message>
    <message>
        <source>Mini mode</source>
        <translation>Минималистичен режим</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Заглушаване</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Следваш кадър</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Предишен кадър</translation>
    </message>
    <message>
        <source>Volume down</source>
        <translation>Намаляване</translation>
    </message>
    <message>
        <source>Volume up</source>
        <translation>Увеличаване</translation>
    </message>
    <message>
        <source>Speed up</source>
        <translation>по-бързо</translation>
    </message>
    <message>
        <source>Speed down</source>
        <translation>по-бавно</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Цял екран</translation>
    </message>
    <message>
        <source>Pause/Play</source>
        <translation>Пауза/Изпълнение</translation>
    </message>
    <message>
        <source>Playlist</source>
        <translation>Списък</translation>
    </message>
    <message>
        <source>Reset speed</source>
        <translation>Нормална скорост</translation>
    </message>
    <message>
        <source>Rewind</source>
        <translation>Връщане</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Напред</translation>
    </message>
    <message>
        <source>Film screenshot</source>
        <translation>Кадър от филма</translation>
    </message>
    <message>
        <source>0.5s backward</source>
        <translation>Назад с 0.5s</translation>
    </message>
    <message>
        <source>0.5s forward</source>
        <translation>Напред с 0.5s</translation>
    </message>
    <message>
        <source>Font</source>
        <translation>Шрифт</translation>
    </message>
    <message>
        <source>Exit fullscreen/mini mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Movie</source>
        <translation>Филм</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Помощ</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Комбинации за екрана</translation>
    </message>
    <message>
        <source>Delete from playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Film info</source>
        <translation>Информация за филм</translation>
    </message>
    <message>
        <source>Burst shooting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <source>Movie is a full-featured video player, supporting playing local and streaming media in multiple video formats.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
    <message>
        <source>Show thumbnails in progress bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default play mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto select (Recommended)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hardware decoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Software decoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Customize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decode mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The custom decoding method needs to be restarted before it can take effect,
and whether to restart it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rendering engine</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UrlDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Отказ</translation>
    </message>
    <message>
        <source>Please enter the URL:</source>
        <translation>Моля въведете URL:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
</context>
<context>
    <name>dmr::ActionFactory</name>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Цял екран</translation>
    </message>
    <message>
        <source>Always on Top</source>
        <translation>Винаги отгоре</translation>
    </message>
    <message>
        <source>Empty playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Film info</source>
        <translation>Информация за филм</translation>
    </message>
    <message>
        <source>Open file</source>
        <translation>Отвори файл</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Отваряне на папка</translation>
    </message>
    <message>
        <source>Open URL</source>
        <translation>Отвори URL</translation>
    </message>
    <message>
        <source>Open CD/DVD</source>
        <translation>Отвори CD/DVD</translation>
    </message>
    <message>
        <source>Mini Mode</source>
        <translation>Минималистичен режим</translation>
    </message>
    <message>
        <source>Play Mode</source>
        <translation>Режим на възпроизвеждане</translation>
    </message>
    <message>
        <source>Order Play</source>
        <translation>Ред на изпълнение</translation>
    </message>
    <message>
        <source>Shuffle Play</source>
        <translation>Разбъркано изпълнение</translation>
    </message>
    <message>
        <source>Single Play</source>
        <translation>Повторение на изпълнението</translation>
    </message>
    <message>
        <source>Single Loop</source>
        <translation>Еднократно повторение</translation>
    </message>
    <message>
        <source>List Loop</source>
        <translation>Повторение на списъка</translation>
    </message>
    <message>
        <source>Frame</source>
        <translation>Кадър</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>По подразбиране</translation>
    </message>
    <message>
        <source>Clockwise</source>
        <translation>По часовниковата</translation>
    </message>
    <message>
        <source>Counterclockwise</source>
        <translation>Обратно на часовниковата</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Звук</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Канал</translation>
    </message>
    <message>
        <source>Stereo</source>
        <translation>Стерео</translation>
    </message>
    <message>
        <source>Left channel</source>
        <translation>Ляв канал</translation>
    </message>
    <message>
        <source>Right channel</source>
        <translation>Десен канал</translation>
    </message>
    <message>
        <source>Track</source>
        <translation>Трак</translation>
    </message>
    <message>
        <source>Subtitle</source>
        <translation>Субтитри</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Зареди</translation>
    </message>
    <message>
        <source>Online Search</source>
        <translation>Търсене онлайн</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Избери</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Скриване</translation>
    </message>
    <message>
        <source>Encodings</source>
        <translation>Кодиране</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Снимка на екрана</translation>
    </message>
    <message>
        <source>Film Screenshot</source>
        <translation>Кадър от филма</translation>
    </message>
    <message>
        <source>Burst Shooting</source>
        <translation>Последователно снимане</translation>
    </message>
    <message>
        <source>Playlist</source>
        <translation>Плейлист</translation>
    </message>
    <message>
        <source>Film Info</source>
        <translation>Информация за филм</translation>
    </message>
    <message>
        <source>Delete from playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Покажи във файловия мениджър</translation>
    </message>
    <message>
        <source>Next Frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous Frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open screenshot folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Playback Speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0.5x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1.0x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1.2x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1.5x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2.0x</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::BurstScreenshotsDialog</name>
    <message>
        <source>Duration: %1</source>
        <translation>Продължителност: %1</translation>
    </message>
    <message>
        <source>Resolution: %1</source>
        <translation>Резолюция: %1</translation>
    </message>
    <message>
        <source>Size: %1</source>
        <translation>Размер: %1</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Запазване</translation>
    </message>
</context>
<context>
    <name>dmr::MainWindow</name>
    <message>
        <source>Load successfully</source>
        <translation>Успешно зареждане</translation>
    </message>
    <message>
        <source>Load failed</source>
        <translation>Неуспешно зареждане</translation>
    </message>
    <message>
        <source>Buffering...</source>
        <translation>Буфериране...</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Отваряне на папка</translation>
    </message>
    <message>
        <source>Stereo</source>
        <translation>Стерео</translation>
    </message>
    <message>
        <source>Left channel</source>
        <translation>Ляв канал</translation>
    </message>
    <message>
        <source>Right channel</source>
        <translation>Десен канал</translation>
    </message>
    <message>
        <source>Parse failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Заглушаване</translation>
    </message>
    <message>
        <source>Volume: %1%</source>
        <translation>Сила на звука: %1</translation>
    </message>
    <message>
        <source>Track: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subtitle %1: %2s</source>
        <translation>Субтитри %1: %2s</translation>
    </message>
    <message>
        <source>delayed</source>
        <translation>забавен</translation>
    </message>
    <message>
        <source>advanced</source>
        <translation>разширен</translation>
    </message>
    <message>
        <source>Speed: %1x</source>
        <translation>Скорост: %1x</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Изглед</translation>
    </message>
    <message>
        <source>Saved to</source>
        <translation>Запази в</translation>
    </message>
    <message>
        <source>The screenshot is saved</source>
        <translation>Снимка на екрана е запазена.</translation>
    </message>
    <message>
        <source>Failed to save the screenshot</source>
        <translation>Не може да се запази снимка на кадъра</translation>
    </message>
    <message>
        <source>Invalid file: %1</source>
        <translation>Невалиден файл: %1</translation>
    </message>
    <message>
        <source>No matching online subtitles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot open file or stream</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid file</source>
        <translation>Невалиден файл</translation>
    </message>
    <message>
        <source>No video file found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Film screenshot</source>
        <translation>Кадър от филма</translation>
    </message>
    <message>
        <source>Taking the screenshots, please wait...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
    <message>
        <source>Please insert a CD/DVD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reading DVD files...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4K video may be stuck</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please load the video first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Order play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shuffle play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>List loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The CD/DVD has been ejected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please exit smart dock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot play the disc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to adjust the subtitle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The action is not supported in this video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
        <comment>All (*)</comment>
        <translation type="unfinished">Субтитри (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Miracast disconnected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Отказ</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfo</name>
    <message>
        <source>%1G</source>
        <translation type="vanished">%1G</translation>
    </message>
    <message>
        <source>%1M</source>
        <translation type="vanished">%1M</translation>
    </message>
    <message>
        <source>%1K</source>
        <translation type="vanished">%1K</translation>
    </message>
    <message>
        <source>%1</source>
        <translation type="vanished">%1</translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfoDialog</name>
    <message>
        <source>Film info</source>
        <translation>Информация за филм</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Резолюция</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Продължителност</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Път</translation>
    </message>
    <message>
        <source>Codec info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FPS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 fps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proportion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1</source>
        <translation type="unfinished">%1</translation>
    </message>
    <message>
        <source>Audio info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio digit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 bits</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sampling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 bps</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::MpvProxy</name>
    <message>
        <source>Internal</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::Platform_MainWindow</name>
    <message>
        <source>Load successfully</source>
        <translation type="unfinished">Успешно зареждане</translation>
    </message>
    <message>
        <source>Load failed</source>
        <translation type="unfinished">Неуспешно зареждане</translation>
    </message>
    <message>
        <source>Cannot play the disc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Parse failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="unfinished">Отваряне на папка</translation>
    </message>
    <message>
        <source>All (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Speed: %1x</source>
        <translation type="unfinished">Скорост: %1x</translation>
    </message>
    <message>
        <source>Stereo</source>
        <translation type="unfinished">Стерео</translation>
    </message>
    <message>
        <source>Left channel</source>
        <translation type="unfinished">Ляв канал</translation>
    </message>
    <message>
        <source>Right channel</source>
        <translation type="unfinished">Десен канал</translation>
    </message>
    <message>
        <source>Track: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to adjust the subtitle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subtitle %1: %2s</source>
        <translation type="unfinished">Субтитри %1: %2s</translation>
    </message>
    <message>
        <source>delayed</source>
        <translation type="unfinished">забавен</translation>
    </message>
    <message>
        <source>advanced</source>
        <translation type="unfinished">разширен</translation>
    </message>
    <message>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
        <comment>All (*)</comment>
        <translation type="unfinished">Субтитри (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
    </message>
    <message>
        <source>View</source>
        <translation type="unfinished">Изглед</translation>
    </message>
    <message>
        <source>Film screenshot</source>
        <translation type="unfinished">Кадър от филма</translation>
    </message>
    <message>
        <source>Saved to</source>
        <translation type="unfinished">Запази в</translation>
    </message>
    <message>
        <source>The screenshot is saved</source>
        <translation type="unfinished">Снимка на екрана е запазена.</translation>
    </message>
    <message>
        <source>Failed to save the screenshot</source>
        <translation type="unfinished">Не може да се запази снимка на кадъра</translation>
    </message>
    <message>
        <source>Taking the screenshots, please wait...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reading DVD files...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No matching online subtitles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4K video may be stuck</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">ОК</translation>
    </message>
    <message>
        <source>Order play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shuffle play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>List loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Buffering...</source>
        <translation type="unfinished">Буфериране...</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation type="unfinished">Заглушаване</translation>
    </message>
    <message>
        <source>Volume: %1%</source>
        <translation type="unfinished">Сила на звука: %1</translation>
    </message>
    <message>
        <source>Cannot open file or stream</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid file</source>
        <translation type="unfinished">Невалиден файл</translation>
    </message>
    <message>
        <source>Please insert a CD/DVD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No video file found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please load the video first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please exit smart dock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The CD/DVD has been ejected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The action is not supported in this video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid file: %1</source>
        <translation type="unfinished">Невалиден файл: %1</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Miracast disconnected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Отказ</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::Platform_PlayItemWidget</name>
    <message>
        <source>The file does not exist</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::Platform_PlaylistWidget</name>
    <message>
        <source>Playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty</source>
        <translation type="unfinished">Празно</translation>
    </message>
    <message>
        <source>%1 videos</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::Platform_ToolboxProxy</name>
    <message>
        <source>Play/Pause</source>
        <translation type="unfinished">Изпълнение/Пауза</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation type="unfinished">Предишно</translation>
    </message>
    <message>
        <source>Next</source>
        <translation type="unfinished">Следващ</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished">Цял екран</translation>
    </message>
    <message>
        <source>Playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation type="unfinished">Изход от цял екран</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="unfinished">Задържане</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished">Изпълнение</translation>
    </message>
    <message>
        <source>Miracast</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::PlayItemWidget</name>
    <message>
        <source>The file does not exist</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::PlaylistWidget</name>
    <message>
        <source>Playlist</source>
        <translation>Плейлист</translation>
    </message>
    <message>
        <source>%1 videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Празно</translation>
    </message>
</context>
<context>
    <name>dmr::Settings</name>
    <message>
        <source>%1/Movie%2(%3).jpg</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Order play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shuffle play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>List loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::ToolboxProxy</name>
    <message>
        <source>Play</source>
        <translation>Изпълнение</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Предишно</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Следващ</translation>
    </message>
    <message>
        <source>Playlist</source>
        <translation>Списък</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Цял екран</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Изпълнение/Пауза</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Изход от цял екран</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Задържане</translation>
    </message>
    <message>
        <source>Miracast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Volume</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::VolumeButton</name>
    <message>
        <source>Volume</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
